This implements the trivial change needed to move back from the hip{Something}_{x, y, z} macros to the natural CUDA syntax of Something.{x, y, z}. This is contained in lines 384-404 in hip_runtime.h. All of the other changes have to do with changing unit tests to use this syntax. The macros are retained for backwards compatibility.

Este commit está contenido en:
Alex Voicu
2017-11-19 01:54:12 +00:00
padre 85975e719d
commit cffd0e14eb
Se han modificado 60 ficheros con 270 adiciones y 248 borrados
+2 -2
Ver fichero
@@ -28,7 +28,7 @@ THE SOFTWARE.
#if __HIP_ARCH_GFX803__ > 0
__global__ void __halfMath(hipLaunchParm lp, __half *A, __half *B, __half *C) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
__half a = A[tx];
__half b = B[tx];
__half c = C[tx];
@@ -44,7 +44,7 @@ __global__ void __halfMath(hipLaunchParm lp, __half *A, __half *B, __half *C) {
}
__global__ void __half2Math(hipLaunchParm lp, __half2 *A, __half2 *B, __half2 *C) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
__half2 a = A[tx];
__half2 b = B[tx];
__half2 c = C[tx];